@@ -117,9 +117,9 @@ haversine <- function(lat1, lon1, lat2, lon2, r = 6371) {
   check_arg(r, "double")
 
   p <- pi / 180
-  a <- 0.5 - cos((lat2 - lat1) * p) / 2 +
-    cos(lat1 * p) * cos(lat2 * p) *
-      (1 - cos((lon2 - lon1) * p)) / 2
+  a <- 0.5 -
+    cos((lat2 - lat1) * p) / 2 +
+    cos(lat1 * p) * cos(lat2 * p) * (1 - cos((lon2 - lon1) * p)) / 2
   return(r * 2 * asin(sqrt(a))) # Equal to 2*R*asin...
 }
 
