@@ -8,10 +8,7 @@ test_that("ccopy", {
     tempfile(file.path("mpathsenser_zip", "test"), fileext = ".zip")
 
   # Zip in the new temp directory
-  utils::zip(zipfile,
-    system.file("testdata", "test.json", package = "mpathsenser"),
-    flags = "-q"
-  )
+  utils::zip(zipfile, system.file("testdata", "test.json", package = "mpathsenser"), flags = "-q")
 
   expect_message(ccopy(zip_dir, zip_dir), "No files left to copy")
   expect_message(ccopy(zip_dir, tempdir()), "Copying 1 files\\.")
@@ -152,9 +149,7 @@ test_that("test_jsons", {
   )
 
   # Test output type if errors are found
-  suppressWarnings(expect_vector(test_jsons(broken_path),
-    ptype = character()
-  ))
+  suppressWarnings(expect_vector(test_jsons(broken_path), ptype = character()))
 
   # Test empty file
   empty <- tempfile(fileext = ".json")
@@ -177,16 +172,17 @@ test_that("test_jsons", {
 
 test_that("unzip_data", {
   # Create directory for zip in tempdir
-  zip_dir <- file.path(tempdir(), "mpathsenser_zip")
+  zip_dir <- tempfile()
   dir.create(zip_dir)
 
   # Define the path for the zip
-  zipfile <- tempfile(file.path("mpathsenser_zip", "test"), fileext = ".zip")
+  zipfile <- file.path(zip_dir, "test.zip")
 
   # Zip in the new temp directory
-  utils::zip(zipfile,
+  utils::zip(
+    zipfile,
     system.file("testdata", "test.json", package = "mpathsenser"),
-    flags = "-q"
+    flags = "-rjq9X"
   )
 
   expect_message(
@@ -204,6 +200,17 @@ test_that("unzip_data", {
     "Unzipped 1 files."
   )
 
+  # Try a mixture of zip and json files
+  file.copy(
+    from = system.file("testdata", "test.json", package = "mpathsenser"),
+    to = file.path(zip_dir, "test2.json"),
+    overwrite = TRUE
+  )
+  expect_message(
+    unzip_data(zip_dir, recursive = FALSE, overwrite = TRUE),
+    "Unzipped 1 files."
+  )
+
   # Get the correct file name in the temp directory and remove
   unlink(zip_dir, recursive = TRUE)
 })
